
Rattail
=======

Rattail is a framework / tool kit for building custom apps.  Originally
intended for use in retail environments, but useful in others also.

It is released under the GNU General Public License.

This is the core ``rattail`` package.

Please see the  `Rattail Project`_ for more information.

.. _Rattail Project: https://rattailproject.org/
